/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.

 Christian Herdtweck, Intra2net AG 2015
 */

#ifndef DNS_CNAME_H
#define DNS_CNAME_H

#include <boost/serialization/access.hpp>
#include <boost/serialization/nvp.hpp>
#include <boost/serialization/split_member.hpp>
#include <boost/serialization/string.hpp>

#include "dns/timetolive.h"

// -----------------------------------------------------------------------------
// CNAME
// -----------------------------------------------------------------------------

struct Cname
{   // all public:
    std::string Host;
    TimeToLive Ttl;

    Cname();
    Cname(const std::string &host, const uint32_t ttl);
    Cname(const std::string &host, const TimeToLive &ttl);

    // serialization
    friend class boost::serialization::access;
    template<class Archive>
    void save(Archive & ar, const unsigned int version) const
    {
        ar & BOOST_SERIALIZATION_NVP(Host);
        ar & BOOST_SERIALIZATION_NVP(Ttl);
    }
    template<class Archive>
    void load(Archive & ar, const unsigned int version)
    {
        ar & BOOST_SERIALIZATION_NVP(Host);
        ar & BOOST_SERIALIZATION_NVP(Ttl);
    }
    BOOST_SERIALIZATION_SPLIT_MEMBER()
};

#endif
